"""Main module."""
from pathlib import Path

import click


class Topojoin:
    def __init__(self, csv_path, topo_path):
        self.csv_path = csv_path
        self.topo_path = topo_path

    @property
    def csv_path(self):
        return self._csv_path

    @csv_path.setter
    def csv_path(self, d):
        p = Path(d)
        if not p.exists():
            raise Exception(f"csv_path must specify a file")
        if p.suffix.lower() not in [".csv"]:
            raise Exception(f"csv_path must have .csv extension")
        self._csv_path = Path(d)

    @property
    def topo_path(self):
        return self._topo_path

    @topo_path.setter
    def topo_path(self, d):
        p = Path(d)
        if not p.exists():
            raise Exception(f"topo_path must specify a file.")
        if p.suffix.lower() not in [".json", ".topojson", ".geojson"]:
            print(p.suffix)
            raise Exception(
                f"topo_path must have .json .topojson or .geojson extension"
            )
        self._topo_path = Path(d)

    def hello(self):
        click.echo(f"csv_path is {self.csv_path}")
        click.echo(f"topo_path is {self.topo_path}")



"""Console script for topojoin."""
import sys
import click

from topojoin.topojoin import Topojoin


@click.command()
@click.argument("csv_path", type=click.STRING)
@click.argument("topo_path", type=click.STRING)
@click.option("--csvkey", "-ck", default="fips", type=click.STRING)
@click.option("--topokey", "-tk", default="fips", type=click.STRING)
def main(csv_path: str, topo_path: str, csvkey: str, topokey: str):
    """Console script for topojoin."""
    click.echo("Starting topojoin...")
    click.echo(csv_path)
    topojoin_obj = Topojoin(csv_path, topo_path)
    topojoin_obj.hello()
    return 0


if __name__ == "__main__":
    sys.exit(main())  # pragma: no cover



#!/usr/bin/env python
"""Tests for `topojoin` package."""
# pylint: disable=redefined-outer-name

import pytest
from click.testing import CliRunner
from pathlib import Path
from topojoin import cli

root = Path(__file__).parent.resolve()


@pytest.fixture
def csv_path():
    return str(root / "fixtures/pa-county-pop.csv")


@pytest.fixture
def topo_path():
    return str(root / "fixtures/pa-county.json")


def test_cli(csv_path, topo_path):
    runner = CliRunner()
    result = runner.invoke(cli.main, [csv_path, topo_path])
    print(result.exc_info)
    print(result.exception)
    assert result.exit_code == 0


def test_cli_help():
    """Test the CLI."""
    runner = CliRunner()
    help_result = runner.invoke(cli.main, ["--help"])
    assert help_result.exit_code == 0
    assert "--help  Show this message and exit." in help_result.output



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['tests', 'topojoin']

package_data = \
{'': ['*'], 'tests': ['fixtures/*']}

install_requires = \
['click']

entry_points = \
{'console_scripts': ['topojoin = topojoin.cli:main']}

setup_kwargs = {
    'name': 'topojoin',
    'version': '0.1.1',
    'description': 'Top-level package for TopoJoin.',
    'long_description': '========\nTopoJoin\n========\n\n\n.. image:: https://img.shields.io/pypi/v/topojoin.svg\n        :target: https://pypi.python.org/pypi/topojoin\n\n.. image:: https://img.shields.io/travis/SimmonsRitchie/topojoin.svg\n        :target: https://travis-ci.com/SimmonsRitchie/topojoin\n\n.. image:: https://readthedocs.org/projects/topojoin/badge/?version=latest\n        :target: https://topojoin.readthedocs.io/en/latest/?badge=latest\n        :alt: Documentation Status\n\n\n\n\nTool to easily join CSV data to topojson.\n\n\n* Free software: MIT\n* Documentation: https://topojoin.readthedocs.io.\n\n\nFeatures\n--------\n\n* TODO\n\nCredits\n-------\n\nThis package was created with Cookiecutter_ and the `briggySmalls/cookiecutter-pypackage`_ project template.\n\n.. _Cookiecutter: https://github.com/audreyr/cookiecutter\n.. _`briggySmalls/cookiecutter-pypackage`: https://github.com/briggySmalls/cookiecutter-pypackage\n',
    'author': 'DSR',
    'author_email': 'info@simmonsritchie.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/SimmonsRitchie/topojoin',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '==3.8.1',
}


setup(**setup_kwargs)
